@@ -2,7 +2,6 @@
 
 namespace Icinga\Module\Businessprocess\Director;
 
-use Icinga\Application\Config;
 use Icinga\Module\Director\Hook\ShipConfigFilesHook;
 use Icinga\Module\Businessprocess\Storage\LegacyStorage;
 
@@ -12,9 +11,7 @@ class ShipConfigFiles extends ShipConfigFilesHook
     {
         $files = array();
 
-        $storage = new LegacyStorage(
-            Config::module('businessprocess')->getSection('global')
-        );
+        $storage = LegacyStorage::getInstance();
 
         foreach ($storage->listProcesses() as $name => $title) {
             $files['processes/' . $name . '.bp'] = $storage->getSource($name);
